redvox.tests.common.test_station_utils API documentation

# Module `redvox.tests.common.test_station_utils`

Expand source code

    import unittest

    import redvox.tests as tests
    from redvox.common.io import ReadFilter
    from redvox.common.api_reader import ApiReader
    from redvox.common import station_utils as su

    class StationMetadataTest(unittest.TestCase):
        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.station_filter = ReadFilter(station_ids={"0000000001"})

        def test_station_metadata(self):
            files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
            metadata = [su.StationMetadata("Redvox", p) for p in files]
            self.assertEqual(len(metadata), 3)
            self.assertEqual(metadata[2].os_version, "Fedora 32")
            self.assertEqual(metadata[1].app_version, "0.2.0")

    class StationPacketMetadataTest(unittest.TestCase):
        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.station_filter = ReadFilter(station_ids={"0000000001"})

        def test_station_packet_metadata(self):
            files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
            metadata = [su.StationPacketMetadata(p) for p in files]
            self.assertEqual(metadata[0].packet_start_mach_timestamp, 1597189452945991.0)

    class StationKeyTest(unittest.TestCase):
        def test_init_key(self):
            key = su.StationKey("test_id", "test_uuid", 0.0)
            other_key = su.StationKey("other_id", "other_uuid", 1.0)
            copy_key = su.StationKey("test_id", "test_uuid", 0.0)
            self.assertEqual(key, copy_key)
            self.assertNotEqual(key, other_key)

## Classes

`class StationKeyTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class StationKeyTest(unittest.TestCase):
          def test_init_key(self):
              key = su.StationKey("test_id", "test_uuid", 0.0)
              other_key = su.StationKey("other_id", "other_uuid", 1.0)
              copy_key = su.StationKey("test_id", "test_uuid", 0.0)
              self.assertEqual(key, copy_key)
              self.assertNotEqual(key, other_key)

  ### Ancestors

  - unittest.case.TestCase

  ### Methods

  `def test_init_key(self)`
    Expand source code

        def test_init_key(self):
            key = su.StationKey("test_id", "test_uuid", 0.0)
            other_key = su.StationKey("other_id", "other_uuid", 1.0)
            copy_key = su.StationKey("test_id", "test_uuid", 0.0)
            self.assertEqual(key, copy_key)
            self.assertNotEqual(key, other_key)

`class StationMetadataTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class StationMetadataTest(unittest.TestCase):
          @classmethod
          def setUpClass(cls) -> None:
              cls.input_dir = tests.TEST_DATA_DIR
              cls.station_filter = ReadFilter(station_ids={"0000000001"})

          def test_station_metadata(self):
              files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
              metadata = [su.StationMetadata("Redvox", p) for p in files]
              self.assertEqual(len(metadata), 3)
              self.assertEqual(metadata[2].os_version, "Fedora 32")
              self.assertEqual(metadata[1].app_version, "0.2.0")

  ### Ancestors

  - unittest.case.TestCase

  ### Static methods

  `def setUpClass() ‑> NoneType`

    Hook method for setting up class fixture before running tests in the class.

    Expand source code

        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.station_filter = ReadFilter(station_ids={"0000000001"})

  ### Methods

  `def test_station_metadata(self)`
    Expand source code

        def test_station_metadata(self):
            files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
            metadata = [su.StationMetadata("Redvox", p) for p in files]
            self.assertEqual(len(metadata), 3)
            self.assertEqual(metadata[2].os_version, "Fedora 32")
            self.assertEqual(metadata[1].app_version, "0.2.0")

`class StationPacketMetadataTest (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class StationPacketMetadataTest(unittest.TestCase):
          @classmethod
          def setUpClass(cls) -> None:
              cls.input_dir = tests.TEST_DATA_DIR
              cls.station_filter = ReadFilter(station_ids={"0000000001"})

          def test_station_packet_metadata(self):
              files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
              metadata = [su.StationPacketMetadata(p) for p in files]
              self.assertEqual(metadata[0].packet_start_mach_timestamp, 1597189452945991.0)

  ### Ancestors

  - unittest.case.TestCase

  ### Static methods

  `def setUpClass() ‑> NoneType`

    Hook method for setting up class fixture before running tests in the class.

    Expand source code

        @classmethod
        def setUpClass(cls) -> None:
            cls.input_dir = tests.TEST_DATA_DIR
            cls.station_filter = ReadFilter(station_ids={"0000000001"})

  ### Methods

  `def test_station_packet_metadata(self)`
    Expand source code

        def test_station_packet_metadata(self):
            files = ApiReader(self.input_dir, read_filter=self.station_filter).read_files_by_id("0000000001")
            metadata = [su.StationPacketMetadata(p) for p in files]
            self.assertEqual(metadata[0].packet_start_mach_timestamp, 1597189452945991.0)